@@ -17,7 +17,7 @@
 #include <KUrlComboBox>
 #include <KUrlRequester>
 
-#include <libkomparediff2/diffsettings.h>
+#include <KompareDiff2/DiffSettings>
 
 #include <kompareshelldebug.h>
 #include "diffpage.h"
@@ -181,3 +181,5 @@ void KompareURLDialog::setSecondURLRequesterMode(unsigned int mode)
 {
     m_filesPage->setSecondURLRequesterMode(mode);
 }
+
+#include "moc_kompareurldialog.cpp"
